@@ -8,7 +8,8 @@ _HTTPSConnection = httplib.HTTPSConnection
 
 try:
     import requests.packages.urllib3.connectionpool
-    _VerifiedHTTPSConnection = requests.packages.urllib3.connectionpool.VerifiedHTTPSConnection 
+    _VerifiedHTTPSConnection = requests.packages.urllib3.connectionpool.VerifiedHTTPSConnection
+    _HTTPConnection = requests.packages.urllib3.connectionpool.HTTPConnection
 except ImportError:
     pass
 
@@ -31,6 +32,8 @@ def install(cassette_path):
         from .requests_stubs import VCRVerifiedHTTPSConnection
         requests.packages.urllib3.connectionpool.VerifiedHTTPSConnection = VCRVerifiedHTTPSConnection
         requests.packages.urllib3.connectionpool.VerifiedHTTPSConnection._vcr_cassette_path = cassette_path
+        requests.packages.urllib3.connectionpool.HTTPConnection = VCRHTTPConnection
+        requests.packages.urllib3.connectionpool.HTTPConnection._vcr_cassette_path = cassette_path
     except ImportError:
         pass
 
@@ -53,6 +56,7 @@ def reset():
     try:
         import requests.packages.urllib3.connectionpool
         requests.packages.urllib3.connectionpool.VerifiedHTTPSConnection = _VerifiedHTTPSConnection
+        requests.packages.urllib3.connectionpool.HTTPConnection = _HTTPConnection
     except ImportError:
         pass
 
